@@ -4,9 +4,9 @@ Main interface for dlm service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_dlm.type_defs import CreateRuleTypeDef
+    from mypy_boto3_dlm.type_defs import ActionTypeDef
 
-    data: CreateRuleTypeDef = {...}
+    data: ActionTypeDef = {...}
     ```
 """
 import sys
@@ -24,9 +24,14 @@ else:
 
 
 __all__ = (
+    "ActionTypeDef",
     "CreateRuleTypeDef",
+    "CrossRegionCopyActionTypeDef",
     "CrossRegionCopyRetainRuleTypeDef",
     "CrossRegionCopyRuleTypeDef",
+    "EncryptionConfigurationTypeDef",
+    "EventParametersTypeDef",
+    "EventSourceTypeDef",
     "FastRestoreRuleTypeDef",
     "LifecyclePolicySummaryTypeDef",
     "LifecyclePolicyTypeDef",
@@ -34,6 +39,7 @@ __all__ = (
     "PolicyDetailsTypeDef",
     "RetainRuleTypeDef",
     "ScheduleTypeDef",
+    "ShareRuleTypeDef",
     "TagTypeDef",
     "CreateLifecyclePolicyResponseTypeDef",
     "GetLifecyclePoliciesResponseTypeDef",
@@ -41,12 +47,33 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
 )
 
+ActionTypeDef = TypedDict(
+    "ActionTypeDef", {"Name": str, "CrossRegionCopy": List["CrossRegionCopyActionTypeDef"]}
+)
+
 CreateRuleTypeDef = TypedDict(
     "CreateRuleTypeDef",
     {"Interval": int, "IntervalUnit": Literal["HOURS"], "Times": List[str], "CronExpression": str},
     total=False,
 )
 
+_RequiredCrossRegionCopyActionTypeDef = TypedDict(
+    "_RequiredCrossRegionCopyActionTypeDef",
+    {"Target": str, "EncryptionConfiguration": "EncryptionConfigurationTypeDef"},
+)
+_OptionalCrossRegionCopyActionTypeDef = TypedDict(
+    "_OptionalCrossRegionCopyActionTypeDef",
+    {"RetainRule": "CrossRegionCopyRetainRuleTypeDef"},
+    total=False,
+)
+
+
+class CrossRegionCopyActionTypeDef(
+    _RequiredCrossRegionCopyActionTypeDef, _OptionalCrossRegionCopyActionTypeDef
+):
+    pass
+
+
 CrossRegionCopyRetainRuleTypeDef = TypedDict(
     "CrossRegionCopyRetainRuleTypeDef",
     {"Interval": int, "IntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
@@ -69,6 +96,37 @@ class CrossRegionCopyRuleTypeDef(
     pass
 
 
+_RequiredEncryptionConfigurationTypeDef = TypedDict(
+    "_RequiredEncryptionConfigurationTypeDef", {"Encrypted": bool}
+)
+_OptionalEncryptionConfigurationTypeDef = TypedDict(
+    "_OptionalEncryptionConfigurationTypeDef", {"CmkArn": str}, total=False
+)
+
+
+class EncryptionConfigurationTypeDef(
+    _RequiredEncryptionConfigurationTypeDef, _OptionalEncryptionConfigurationTypeDef
+):
+    pass
+
+
+EventParametersTypeDef = TypedDict(
+    "EventParametersTypeDef",
+    {"EventType": Literal["shareSnapshot"], "SnapshotOwner": List[str], "DescriptionRegex": str},
+)
+
+_RequiredEventSourceTypeDef = TypedDict(
+    "_RequiredEventSourceTypeDef", {"Type": Literal["MANAGED_CWE"]}
+)
+_OptionalEventSourceTypeDef = TypedDict(
+    "_OptionalEventSourceTypeDef", {"Parameters": "EventParametersTypeDef"}, total=False
+)
+
+
+class EventSourceTypeDef(_RequiredEventSourceTypeDef, _OptionalEventSourceTypeDef):
+    pass
+
+
 _RequiredFastRestoreRuleTypeDef = TypedDict(
     "_RequiredFastRestoreRuleTypeDef", {"AvailabilityZones": List[str]}
 )
@@ -90,6 +148,7 @@ LifecyclePolicySummaryTypeDef = TypedDict(
         "Description": str,
         "State": Literal["ENABLED", "DISABLED", "ERROR"],
         "Tags": Dict[str, str],
+        "PolicyType": Literal["EBS_SNAPSHOT_MANAGEMENT", "IMAGE_MANAGEMENT", "EVENT_BASED_POLICY"],
     },
     total=False,
 )
@@ -111,16 +170,20 @@ LifecyclePolicyTypeDef = TypedDict(
     total=False,
 )
 
-ParametersTypeDef = TypedDict("ParametersTypeDef", {"ExcludeBootVolume": bool}, total=False)
+ParametersTypeDef = TypedDict(
+    "ParametersTypeDef", {"ExcludeBootVolume": bool, "NoReboot": bool}, total=False
+)
 
 PolicyDetailsTypeDef = TypedDict(
     "PolicyDetailsTypeDef",
     {
-        "PolicyType": Literal["EBS_SNAPSHOT_MANAGEMENT"],
+        "PolicyType": Literal["EBS_SNAPSHOT_MANAGEMENT", "IMAGE_MANAGEMENT", "EVENT_BASED_POLICY"],
         "ResourceTypes": List[Literal["VOLUME", "INSTANCE"]],
         "TargetTags": List["TagTypeDef"],
         "Schedules": List["ScheduleTypeDef"],
         "Parameters": "ParametersTypeDef",
+        "EventSource": "EventSourceTypeDef",
+        "Actions": List["ActionTypeDef"],
     },
     total=False,
 )
@@ -142,10 +205,23 @@ ScheduleTypeDef = TypedDict(
         "RetainRule": "RetainRuleTypeDef",
         "FastRestoreRule": "FastRestoreRuleTypeDef",
         "CrossRegionCopyRules": List["CrossRegionCopyRuleTypeDef"],
+        "ShareRules": List["ShareRuleTypeDef"],
     },
     total=False,
 )
 
+_RequiredShareRuleTypeDef = TypedDict("_RequiredShareRuleTypeDef", {"TargetAccounts": List[str]})
+_OptionalShareRuleTypeDef = TypedDict(
+    "_OptionalShareRuleTypeDef",
+    {"UnshareInterval": int, "UnshareIntervalUnit": Literal["DAYS", "WEEKS", "MONTHS", "YEARS"]},
+    total=False,
+)
+
+
+class ShareRuleTypeDef(_RequiredShareRuleTypeDef, _OptionalShareRuleTypeDef):
+    pass
+
+
 TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
 
 CreateLifecyclePolicyResponseTypeDef = TypedDict(
